[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- doapfiend: http://trac.doapspace.org/doapfiend
  - doapfiend.cli: Command-line tool for querying, serializing and displaying DOAP
  - doapfiend.doaplib: Library for parsing, displaying, querying and serializing DOAP
  - doapfiend.model: Model of a DOAP profile using RDFAlchemy
  - doapfiend.utils: General purpose helper functions and classes for doapfiend You'll probably want to use doaplib for most cases.